==> react-hr-component-kc-1.0.0.tgz: package/src/components/UiConfiguratorScm.js <==
import React from "react";
import LeftNavigationUiConfigurator from "./LeftNavigationUiConfigurator";
import { Form, Row, Col, Button } from "react-bootstrap";

function UiConfiguratorScm() {
  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Configure SCM</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/configure-scm">Configure SCM</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">
                  <LeftNavigationUiConfigurator />
                </div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div>
                      <Form>
                        <Form.Group
                          as={Row}
                          controlId="configureScmCredentials"
                        >
                          <Form.Label column sm={2}>
                            Credentials <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              onChange={props.scmCredentialsChange}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="configureScmGitUrl">
                          <Form.Label column sm={2}>
                            Git URL <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              onChange={props.scmGitUrlChange}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="configureScmRepoName">
                          <Form.Label column sm={2}>
                            Repo Name <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              onChange={props.scmRepoNameChange}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="configureScmRepoUrl">
                          <Form.Label column sm={2}>
                            Repo URL <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              onChange={props.scmRepoUrlChange}
                            />
                          </Col>
                        </Form.Group>
                      </Form>
                      <div className="text-right">
                        <Button
                          variant="primary"
                          onClick={props.configureJenkinsSubmit}
                        >
                          Submit
                        </Button>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UiConfiguratorScm;

==> react-hr-component-kc-1.0.1.tgz: package/src/components/UiConfiguratorScm.js <==
import React, { useState, useEffect } from "react";
import LeftNavigationUiConfigurator from "./LeftNavigationUiConfigurator";
import { Form, Row, Col, Button } from "react-bootstrap";
import axios from "axios";

function UiConfiguratorScm(props) {
  const [scmCredential, setScmCredential] = useState("");
  const [scmGitUrl, setScmGitUrl] = useState("");
  const [scmRepoName, setScmRepoName] = useState("");
  const [scmRepoUrl, setScmRepoUrl] = useState("");

  const scmCredentialsChangeHandler = (event) => {
    setScmCredential(event.target.value);
    console.log(scmCredential);
  };

  const scmGitUrlChangeHandler = (event) => {
    setScmGitUrl(event.target.value);
    console.log(scmGitUrl);
  };

  const scmRepoNameChangeHandler = (event) => {
    setScmRepoName(event.target.value);
    console.log(scmRepoName);
  };

  const scmRepoUrlChangeHandler = (event) => {
    setScmRepoUrl(event.target.value);
    console.log(scmRepoUrl);
  };

  const configureScmSubmitHandler = () => {
    axios.get("http://35.184.81.221:9001/globalConfig/scm").then((resp) => {
      console.log(resp);
    });
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Configure SCM</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/configure-scm">Configure SCM</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">
                  <LeftNavigationUiConfigurator />
                </div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div>
                      <Form>
                        <Form.Group
                          as={Row}
                          controlId="configureScmCredentials"
                        >
                          <Form.Label column sm={2}>
                            Credentials <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              //onChange={props.scmCredentialsChange}
                              onChange={scmCredentialsChangeHandler}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="configureScmGitUrl">
                          <Form.Label column sm={2}>
                            Git URL <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              //onChange={props.scmGitUrlChange}
                              onChange={scmGitUrlChangeHandler}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="configureScmRepoName">
                          <Form.Label column sm={2}>
                            Repo Name <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              //onChange={props.scmRepoNameChange}
                              onChange={scmRepoNameChangeHandler}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="configureScmRepoUrl">
                          <Form.Label column sm={2}>
                            Repo URL <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              //onChange={props.scmRepoUrlChange}
                              onChange={scmRepoUrlChangeHandler}
                            />
                          </Col>
                        </Form.Group>
                      </Form>
                      <div className="text-right">
                        <Button
                          variant="primary"
                          onClick={configureScmSubmitHandler}
                        >
                          Submit
                        </Button>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UiConfiguratorScm;
